@@ -3,7 +3,7 @@
  *****************************************************************************
  * Copyright (C) 2022 MX Authors
  *
- * Authors: Adrian
+ * Authors: Adrian <adrian@mxlinux.org>
  *          MX Linux <http://mxlinux.org>
  *
  * This program is free software: you can redistribute it and/or modify
@@ -29,11 +29,10 @@ class AddressBar : public QLineEdit
     Q_OBJECT
 
 public:
-    AddressBar(QWidget *parent = nullptr);
+    explicit AddressBar(QWidget *parent = nullptr);
 
 private slots:
     void focusInEvent(QFocusEvent *event) override;
-
 };
 
 #endif // ADDRESSBAR_H
