@@ -9,92 +9,92 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../downloadwidget.cpp" line="39"/>
+        <location filename="../downloadwidget.cpp" line="42"/>
         <source>Save as</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../downloadwidget.cpp" line="46"/>
+        <location filename="../downloadwidget.cpp" line="50"/>
         <source>cancel</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../downloadwidget.cpp" line="85"/>
+        <location filename="../downloadwidget.cpp" line="89"/>
         <source>%L1 B</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../downloadwidget.cpp" line="87"/>
+        <location filename="../downloadwidget.cpp" line="91"/>
         <source>%L1 KiB</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../downloadwidget.cpp" line="89"/>
+        <location filename="../downloadwidget.cpp" line="93"/>
         <source>%L1 MiB</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../downloadwidget.cpp" line="91"/>
+        <location filename="../downloadwidget.cpp" line="95"/>
         <source>%L1 GiB</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../downloadwidget.cpp" line="97"/>
+        <location filename="../downloadwidget.cpp" line="102"/>
         <source>%1sec.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../downloadwidget.cpp" line="99"/>
+        <location filename="../downloadwidget.cpp" line="104"/>
         <source>%1min. %2sec.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../downloadwidget.cpp" line="101"/>
+        <location filename="../downloadwidget.cpp" line="106"/>
         <source>%1h. %2m. %3s.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../downloadwidget.cpp" line="120"/>
+        <location filename="../downloadwidget.cpp" line="126"/>
         <source>%p% - %1 of %2 at %3/s - %4 left</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../downloadwidget.cpp" line="127"/>
+        <location filename="../downloadwidget.cpp" line="133"/>
         <source>unknown size - %1 at %2/s</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../downloadwidget.cpp" line="133"/>
+        <location filename="../downloadwidget.cpp" line="139"/>
         <source>completed - %1 at %2/s</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../downloadwidget.cpp" line="138"/>
+        <location filename="../downloadwidget.cpp" line="144"/>
         <source>cancelled</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../downloadwidget.cpp" line="143"/>
+        <location filename="../downloadwidget.cpp" line="149"/>
         <source>interrupted: %1</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../downloadwidget.cpp" line="149"/>
+        <location filename="../downloadwidget.cpp" line="155"/>
         <source>Cancel</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../downloadwidget.cpp" line="150"/>
+        <location filename="../downloadwidget.cpp" line="156"/>
         <source>Cancel downloading</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../downloadwidget.cpp" line="153"/>
+        <location filename="../downloadwidget.cpp" line="159"/>
         <source>Remove</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../downloadwidget.cpp" line="154"/>
+        <location filename="../downloadwidget.cpp" line="160"/>
         <source>Remove from list</source>
         <translation type="unfinished"></translation>
     </message>
@@ -110,12 +110,12 @@
         <translation type="vanished">खोज</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="243"/>
+        <location filename="../mainwindow.cpp" line="257"/>
         <source>Select file to open</source>
         <translation>उपयोग हेतु फाइल चयन</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="244"/>
+        <location filename="../mainwindow.cpp" line="258"/>
         <source>Hypertext Files (*.htm *.html);;All Files (*.*)</source>
         <translation>हाइपरटेक्स्ट फाइलें (*.htm *.html);;सभी फाइलें (*.*)</translation>
     </message>
@@ -128,183 +128,188 @@
         <translation type="vanished">साइट या फाइल यूआरएल दर्ज करें :</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="70"/>
+        <location filename="../mainwindow.cpp" line="90"/>
         <source>Full screen</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="85"/>
+        <location filename="../mainwindow.cpp" line="106"/>
         <source>Move up</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="95"/>
+        <location filename="../mainwindow.cpp" line="116"/>
         <source>Move down</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="103"/>
+        <location filename="../mainwindow.cpp" line="125"/>
         <source>Rename</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="106"/>
+        <location filename="../mainwindow.cpp" line="128"/>
         <source>Save</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="108"/>
+        <location filename="../mainwindow.cpp" line="130"/>
         <source>Rename bookmark:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="113"/>
-        <location filename="../mainwindow.cpp" line="127"/>
+        <location filename="../mainwindow.cpp" line="136"/>
+        <location filename="../mainwindow.cpp" line="151"/>
         <source>Delete</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="140"/>
+        <location filename="../mainwindow.cpp" line="169"/>
         <source>&amp;Clear history</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="181"/>
+        <location filename="../mainwindow.cpp" line="189"/>
         <source>Home</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="192"/>
+        <location filename="../mainwindow.cpp" line="209"/>
         <source>search in page</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="206"/>
+        <location filename="../mainwindow.cpp" line="223"/>
         <source>Add bookmark</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="212"/>
+        <location filename="../mainwindow.cpp" line="194"/>
         <source>Zoom out</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="216"/>
+        <location filename="../mainwindow.cpp" line="191"/>
         <source>Zoom In</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="219"/>
+        <location filename="../mainwindow.cpp" line="232"/>
         <source>Settings</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="345"/>
+        <location filename="../mainwindow.cpp" line="374"/>
         <source>Keyboard Shortcuts</source>
         <translation>कुंजीपटल शॉर्टकट</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="346"/>
+        <location filename="../mainwindow.cpp" line="375"/>
         <source>Ctrl-F, or F3</source>
         <translation>Ctrl-F, या F3</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="346"/>
+        <location filename="../mainwindow.cpp" line="375"/>
         <source>Find</source>
         <translation>खोजें</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="346"/>
+        <location filename="../mainwindow.cpp" line="375"/>
         <source>Shift-F3</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="347"/>
+        <location filename="../mainwindow.cpp" line="376"/>
         <source>Ctrl-R, or F5</source>
         <translation>Ctrl-R, या F5</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="347"/>
+        <location filename="../mainwindow.cpp" line="376"/>
         <source>Reload</source>
         <translation>पुनः लोड करें</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="347"/>
+        <location filename="../mainwindow.cpp" line="376"/>
         <source>Find previous</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="348"/>
+        <location filename="../mainwindow.cpp" line="377"/>
         <source>Ctrl-O</source>
         <translation>Ctrl-O</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="348"/>
+        <location filename="../mainwindow.cpp" line="377"/>
         <source>Esc</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="349"/>
+        <location filename="../mainwindow.cpp" line="378"/>
         <source>Stop loading/clear Find field</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="349"/>
+        <location filename="../mainwindow.cpp" line="378"/>
         <source>Alt→, Alt←</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="397"/>
+        <location filename="../mainwindow.cpp" line="437"/>
         <source>Press [F11] to exit full screen</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="455"/>
+        <location filename="../mainwindow.cpp" line="521"/>
+        <source>&amp;New tab</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="524"/>
         <source>&amp;Full screen</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="457"/>
+        <location filename="../mainwindow.cpp" line="526"/>
         <source>H&amp;istory</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="460"/>
+        <location filename="../mainwindow.cpp" line="529"/>
         <source>&amp;Downloads</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="463"/>
+        <location filename="../mainwindow.cpp" line="532"/>
         <source>&amp;Bookmarks</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="466"/>
+        <location filename="../mainwindow.cpp" line="535"/>
         <source>Bookmark current address</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="470"/>
+        <location filename="../mainwindow.cpp" line="539"/>
         <source>&amp;Help</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="471"/>
+        <location filename="../mainwindow.cpp" line="540"/>
         <source>&amp;About</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="473"/>
+        <location filename="../mainwindow.cpp" line="542"/>
         <source>&amp;Exit</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="500"/>
+        <location filename="../mainwindow.cpp" line="571"/>
         <source>About MX Viewer</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="501"/>
+        <location filename="../mainwindow.cpp" line="572"/>
         <source>This is a VERY basic browser based on Qt WebEngine.
 
 The main purpose is to provide a basic document viewer for MX documentation. It could be used for LIMITED internet browsing, but it&apos;s not recommended to be used for anything important or secure because it&apos;s not a fully featured browser and its security/privacy features were not tested.
@@ -325,7 +330,7 @@ You should have received a copy of the GNU General Public License along with MX
         <translation type="vanished">Ctrl-B</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="348"/>
+        <location filename="../mainwindow.cpp" line="377"/>
         <source>Browse file to open</source>
         <translation>उपयोग हेतु फाइल देखें</translation>
     </message>
@@ -338,17 +343,17 @@ You should have received a copy of the GNU General Public License along with MX
         <translation type="vanished">Alt-बायीं तीर कुंजी, Alt-दायीं तीर कुंजी</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="350"/>
+        <location filename="../mainwindow.cpp" line="379"/>
         <source>Back/Forward</source>
         <translation>वापस/आगे</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="350"/>
+        <location filename="../mainwindow.cpp" line="379"/>
         <source>F1, or ?</source>
         <translation>F1, या ?</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="350"/>
+        <location filename="../mainwindow.cpp" line="379"/>
         <source>Open this help dialog</source>
         <translation>यह सहायता विंडो खोलें</translation>
     </message>
@@ -360,7 +365,7 @@ You should have received a copy of the GNU General Public License along with MX
         <translation type="vanished">यह साधन यूआरएल सामग्री को विंडो में प्रदर्शित करेगा, विंडो शीर्षक वैकल्पिक है।</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="93"/>
+        <location filename="../main.cpp" line="98"/>
         <source>Disable JavaScript</source>
         <translation>जावा स्क्रिप्ट निष्क्रिय करें</translation>
     </message>
@@ -369,7 +374,7 @@ You should have received a copy of the GNU General Public License along with MX
         <translation type="vanished">विकृत साइट हेतु समाधान निष्क्रिय करें</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="102"/>
+        <location filename="../main.cpp" line="108"/>
         <source>Enable spatial navigation with keyboard</source>
         <translation>कुंजीपटल द्वारा स्थानिक संचालन सक्रिय करें</translation>
     </message>
@@ -378,44 +383,52 @@ You should have received a copy of the GNU General Public License along with MX
         <translation type="vanished">अन्य स्रोत युक्त कुकीज़ सक्रिय करें</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="86"/>
+        <location filename="../main.cpp" line="91"/>
         <source>This tool will display the URL content in a window, window title is optional</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="90"/>
+        <location filename="../main.cpp" line="95"/>
         <source>Start program in full-screen mode</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="92"/>
+        <location filename="../main.cpp" line="97"/>
         <source>Disable load images automatically from websites</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="97"/>
+        <location filename="../main.cpp" line="102"/>
         <source>Drop program&apos;s rights to &apos;nobody&apos;. By default, if run as root, the rights are dropped to normal user. This option might provide additional protection, but the program would not be able to write its cache and cookies to the user directory, so it might break some functionality.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="103"/>
+        <location filename="../main.cpp" line="109"/>
         <source>URL</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="104"/>
+        <location filename="../main.cpp" line="110"/>
         <source>URL of the page you want to load</source>
         <translation>इच्छित पृष्ठ का यूआरएल</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="106"/>
+        <location filename="../main.cpp" line="112"/>
         <source>Window title for the viewer</source>
         <translation>प्रदर्शक हेतु विंडो शीर्षक</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="106"/>
+        <location filename="../main.cpp" line="112"/>
         <source>Title</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
+<context>
+    <name>TabWidget</name>
+    <message>
+        <location filename="../tabwidget.cpp" line="72"/>
+        <source>New Tab</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 </TS>
